@@ -1,4 +1,7 @@
-from ConfigParser import SafeConfigParser
+try:
+    from ConfigParser import SafeConfigParser
+except ImportError:
+    from configparser import SafeConfigParser
 import os
 
 from .constants import LICENSES
